==> org.eclipse.sirius.diagram.source_3.0.1.201509081015.jar: org/eclipse/sirius/diagram/business/internal/repair/resource/session/diagram/data/LostDiagramData.java <==
/*******************************************************************************
 * Copyright (c) 2010 THALES GLOBAL SERVICES.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.business.internal.repair.resource.session.diagram.data;

import org.eclipse.sirius.diagram.DDiagram;
import org.eclipse.sirius.diagram.DDiagramElement;
import org.eclipse.sirius.viewpoint.DSemanticDecorator;

/**
 * Lost diagram element data.
 * 
 * @author dlecan
 */
public class LostDiagramData extends AbstractLostElementDataWithTarget implements ILostElementDataContainer {

    /**
     * {@inheritDoc}
     */
    public LostElementDataState addDiagramElementInCorrespondingParentContainer(final DDiagram diagram, final DDiagramElement diagramElement) {
        return diagram.getOwnedDiagramElements().add(diagramElement) ? LostElementDataState.CREATED : LostElementDataState.NOT_CREATED;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return super.toString() + " Diagram data";
    }

    /**
     * {@inheritDoc}
     */
    public boolean isSimilarTo(final DSemanticDecorator semanticDecorator) {
        // Works for null values too
        return getTarget() == semanticDecorator.getTarget();
    }
}

==> org.eclipse.sirius.diagram.source_7.4.5.202411261603.jar: org/eclipse/sirius/diagram/business/internal/repair/resource/session/diagram/data/LostDiagramData.java <==
/*******************************************************************************
 * Copyright (c) 2010 THALES GLOBAL SERVICES.
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.business.internal.repair.resource.session.diagram.data;

import org.eclipse.sirius.diagram.DDiagram;
import org.eclipse.sirius.diagram.DDiagramElement;
import org.eclipse.sirius.viewpoint.DSemanticDecorator;

/**
 * Lost diagram element data.
 * 
 * @author dlecan
 */
public class LostDiagramData extends AbstractLostElementDataWithTarget implements ILostElementDataContainer {

    /**
     * {@inheritDoc}
     */
    @Override
    public LostElementDataState addDiagramElementInCorrespondingParentContainer(final DDiagram diagram, final DDiagramElement diagramElement) {
        return diagram.getOwnedDiagramElements().add(diagramElement) ? LostElementDataState.CREATED : LostElementDataState.NOT_CREATED;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return super.toString() + " Diagram data"; //$NON-NLS-1$
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isSimilarTo(final DSemanticDecorator semanticDecorator) {
        // Works for null values too
        return getTarget() == semanticDecorator.getTarget();
    }
}
